@@ -13,6 +13,9 @@ tab_cross = function(vr, vrby
   var_cross(newvr = newvr, vr = vr, vrby = vrby)
 
   design = .load_survey()
+  attr(design$variables[,newvr], "label") = paste0(
+    "(", .getvarname(design, vr), ") x ("
+    , .getvarname(design, vrby), ")")
   ret = .tab_factor(design = design, vr = newvr
                     , drop_na = FALSE
                 , max_levels = max_levels
