@@ -3,6 +3,7 @@
 #' @param newvr   name of the new logical variable to be created
 #' @param vr factor variable
 #' @param cases one or more levels of `vr` that are converted to `TRUE`. All other levels are converted to `FALSE`.
+#' @param retain_na for the observations where `vr` is `NA`, should `newvr` be `NA` as well?
 #'
 #' @return Survey object
 #' @family variables
@@ -10,13 +11,21 @@
 #'
 #' @examples
 #' set_survey(namcs2019sv)
+#'
 #' var_case("Preventive care visits", "MAJOR", "Preventive care")
 #' tab("Preventive care visits")
+#'
 #' var_case("Surgery-related visits"
 #' , "MAJOR"
 #' , c("Pre-surgery", "Post-surgery"))
 #' tab("Surgery-related visits")
-var_case = function(newvr, vr, cases) {
+#'
+#' var_case("Non-primary"
+#' , "SPECCAT.bad"
+#' , c("Surgical care specialty", "Medical care specialty"))
+#' tab("Non-primary")
+#' tab("Non-primary", drop_na = TRUE)
+var_case = function(newvr, vr, cases, retain_na = TRUE) {
   design = .load_survey()
   nm = names(design$variables)
   assert_that(vr %in% nm, msg = paste("Variable", vr, "not in the data."))
@@ -30,6 +39,10 @@ var_case = function(newvr, vr, cases) {
   }
 
   design$variables[,newvr] = FALSE
+  if (retain_na) {
+    idx = which(is.na(design$variables[,vr]))
+    design$variables[idx, newvr] = NA
+  }
   idx = which(design$variables[,vr] %in% cases)
   design$variables[idx, newvr] = TRUE
 
